Adds the new prediction and simulation tables to an existing database. This is a non-destructive migration that preserves all existing data.
Adds the new prediction and simulation tables to an existing database. This is a non-destructive migration that preserves all existing data.