Ensures player ELO stays within defined bounds to prevent extreme drift. Uses THREE_WAY_PLAYER_ELO_MIN and THREE_WAY_PLAYER_ELO_MAX constants.
Ensures player ELO stays within defined bounds to prevent extreme drift. Uses THREE_WAY_PLAYER_ELO_MIN and THREE_WAY_PLAYER_ELO_MAX constants.