Estimate Test Match Total Overs
Source:R/score_projection_test_match.R
estimate_test_total_overs.RdEstimates the total overs available in a Test match based on duration.

R/score_projection_test_match.R
estimate_test_total_overs.RdEstimates the total overs available in a Test match based on duration.