Finds or creates the bouncerdata directory for storing data files. Prefers project-local directory (bouncerverse/bouncerdata) if it exists, otherwise falls back to system data directory.
Finds or creates the bouncerdata directory for storing data files. Prefers project-local directory (bouncerverse/bouncerdata) if it exists, otherwise falls back to system data directory.