Skip to contents

Emergency function to release file locks when you get "file is being used by another process" errors.

Usage

force_close_duckdb()

Value

Invisibly returns TRUE

Details

This function:

  1. Forces garbage collection to finalize orphaned connections

  2. Attempts to shutdown any DuckDB driver instances

If the file is still locked after calling this, restart R with Ctrl+Shift+F10.

Examples

if (FALSE) { # \dontrun{
# If you get a file lock error:
force_close_duckdb()

# Then retry your operation
install_all_bouncer_data(fresh = TRUE)
} # }