Skip to contents

Returns the format codes that can be used with fox_discover_matches(), fox_fetch_matches(), and fox_combine_matches().

Usage

fox_list_formats(details = FALSE)

Arguments

details

If TRUE, return a data.frame with format details. If FALSE (default), return just the format codes as a character vector.

Value

Character vector of format codes, or data.frame with details

Examples

fox_list_formats()
#>  [1] "TEST"   "T20I"   "WT20I"  "ODI"    "WODI"   "BBL"    "WBBL"   "WNCL"  
#>  [9] "WPL"    "IPL"    "SHEF"   "T20WC"  "WT20WC" "CT"     "ODIWC" 
fox_list_formats(details = TRUE)
#>    format prefix max_innings max_series max_matches
#> 1    TEST   TEST           4         15           7
#> 2    T20I   T20I           2         30          10
#> 3   WT20I  WT20I           2         30          10
#> 4     ODI    ODI           2         20           7
#> 5    WODI   WODI           2         20           7
#> 6     BBL    BBL           2         10          70
#> 7    WBBL   WBBL           2         10          70
#> 8    WNCL   WNCL           2         10          30
#> 9     WPL    WPL           2          5          30
#> 10    IPL    IPL           2          5          80
#> 11   SHEF   SHEF           4          5          40
#> 12  T20WC  T20WC           2          3          60
#> 13 WT20WC WT20WC           2          3          35
#> 14     CT     CT           2          3          20
#> 15  ODIWC  ODIWC           2          3          55