Convenience function returning upcoming matches within a date window.
Usage
get_upcoming_matches(
format = "all",
gender = "all",
days_ahead = 30,
source = c("remote", "local")
)Convenience function returning upcoming matches within a date window.
get_upcoming_matches(
format = "all",
gender = "all",
days_ahead = 30,
source = c("remote", "local")
)