Load match-level metadata including venue, teams, officials, and Hawkeye source information.
Usage
load_cricinfo_match(
match_ids = NULL,
format = NULL,
gender = NULL,
source = c("remote", "local")
)Load match-level metadata including venue, teams, officials, and Hawkeye source information.
load_cricinfo_match(
match_ids = NULL,
format = NULL,
gender = NULL,
source = c("remote", "local")
)