Load innings-level summaries from local DuckDB or remote GitHub releases. Includes target info, super over flags, and absent hurt data.
Usage
load_innings(
match_type = "all",
gender = "all",
match_ids = NULL,
source = c("local", "remote")
)Load innings-level summaries from local DuckDB or remote GitHub releases. Includes target info, super over flags, and absent hurt data.
load_innings(
match_type = "all",
gender = "all",
match_ids = NULL,
source = c("local", "remote")
)