Load team skill indices for a specific format or all formats.
Usage
load_team_skill(match_type = "all", source = c("local", "remote"))Load team skill indices for a specific format or all formats.
load_team_skill(match_type = "all", source = c("local", "remote"))