Returns a leaderboard of player career ratings combining EPR, PSR, and BOUNCER composite ratings.
Usage
player_career_ratings(
format = c("t20", "odi", "test"),
role_filter = "all",
n_top = 20,
min_matches = 10
)Returns a leaderboard of player career ratings combining EPR, PSR, and BOUNCER composite ratings.
player_career_ratings(
format = c("t20", "odi", "test"),
role_filter = "all",
n_top = 20,
min_matches = 10
)