Search for teams in the database.
See also
get_team to get detailed info for a specific team,
compare_teams to compare two teams
Search for teams in the database.
get_team to get detailed info for a specific team,
compare_teams to compare two teams