User-facing function to connect to the Bouncer cricket database. Use this connection to query data directly with SQL if needed.
Examples
if (FALSE) { # \dontrun{
# Connect to database
conn <- connect_to_bouncer()
# Query data
matches <- DBI::dbGetQuery(conn, "SELECT * FROM cricsheet.matches LIMIT 10")
# Always disconnect when done
disconnect_bouncer(conn)
} # }