Emergency function to release file locks when you get "file is being used by another process" errors.
Details
This function:
Forces garbage collection to finalize orphaned connections
Attempts to shutdown any DuckDB driver instances
If the file is still locked after calling this, restart R with Ctrl+Shift+F10.
Examples
if (FALSE) { # \dontrun{
# If you get a file lock error:
force_close_duckdb()
# Then retry your operation
install_all_bouncer_data(fresh = TRUE)
} # }